@@ -1,7 +1,7 @@
 
 package OODoc::Format::Pod2;
 use vars '$VERSION';
-$VERSION = '0.08';
+$VERSION = '0.09';
 use base 'OODoc::Format::Pod';
 
 use strict;
@@ -48,7 +48,8 @@ sub formatManual(@)
      ( { -lookups => \%permitted }
      );
 
-    my $created = $template->output($self->{O_template});
+    my $layout  = ${$self->{O_template}};        # Copy needed by template!
+    my $created = $template->output(\$layout);
     $output->print($$created);
 }
 
